import flask, flask_cors, flask_talisman
from flask_talisman import ALLOW_FROM

from ...stdio_monkey_patch import override_stdio
from ..controller import MainController
from ...settings import SettingsController
from ..blueprints.player import get_player_bp
from ...utils.environment import ENABLE_TALISMAN


def get_cloud_app(root: str):
    SettingsController.set_root_path(root)
    SettingsController.set_server_port(None)

    override_stdio(print_exceptions=True)
    controller = MainController()
    app = flask.Flask(__name__)
    flask_cors.CORS(app)

    if ENABLE_TALISMAN:
        talisman = flask_talisman.Talisman(
            app,
            content_security_policy={"frame-ancestors": ["*"]},
            frame_options=ALLOW_FROM,
            frame_options_allow_from="*",
        )

        @app.route("/_healthcheck")
        @talisman(force_https=False)
        def _healthcheck():
            return "ok"

    else:

        @app.route("/_healthcheck")
        def _healthcheck():
            return "ok"

    player = get_player_bp(controller)
    app.register_blueprint(player)

    return app



from .ImageInput import ImageInput
from .CheckboxInput import CheckboxInput
from .ToggleInput import ToggleInput
from .VideoInput import VideoInput
from .RatingInput import RatingInput
from .PandasOutput import PandasOutput
from .TimeInput import TimeInput
from .ChecklistInput import ChecklistInput
from .DropdownInput import DropdownInput
from .ImageOutput import ImageOutput
from .CurrencyInput import CurrencyInput
from .DateInput import DateInput
from .CustomInput import CustomInput
from .NumberSliderInput import NumberSliderInput
from .NpsInput import NpsInput
from .EmailInput import EmailInput
from .FileInput import FileInput
from .NumberInput import NumberInput
from .TextInput import TextInput
from .CameraInput import CameraInput
from .ProgressOutput import ProgressOutput
from .TagInput import TagInput
from .PandasRowSelectionInput import PandasRowSelectionInput
from .MarkdownOutput import MarkdownOutput
from .CnpjInput import CnpjInput
from .PhoneInput import PhoneInput
from .CardsInput import CardsInput
from .PasswordInput import PasswordInput
from .CpfInput import CpfInput
from .TextOutput import TextOutput
from .TextareaInput import TextareaInput
from .IframeOutput import IframeOutput
from .MultipleChoiceInput import MultipleChoiceInput
from .FileOutput import FileOutput
from .RichTextInput import RichTextInput
from .ListInput import ListInput
from .CodeInput import CodeInput
from .HtmlOutput import HtmlOutput
from .LinkOutput import LinkOutput
from .LatexOutput import LatexOutput
from .PlotlyOutput import PlotlyOutput
